/* hercules.h - hercules console interface */
/*
 *  GRUB  --  GRand Unified Bootloader
 *  Copyright (C) 2001  Free Software Foundation, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef GRUB_HERCULES_HEADER
#define GRUB_HERCULES_HEADER	1

/* Macros.  */
#define HERCULES_VIDEO_ADDR	RAW_ADDR (0xB0000)
#define HERCULES_WIDTH		80
#define HERCULES_HEIGHT		25
#define HERCULES_INDEX_REG	0x3b4
#define HERCULES_DATA_REG	0x3b5

#endif /* ! GRUB_HERCULES_HEADER */
